# Generated by roxygen2: do not edit by hand

S3method(anova,mev_gev)
S3method(anova,mev_gpd)
S3method(anova,mev_pp)
S3method(coef,mev_egp)
S3method(coef,mev_gev)
S3method(coef,mev_gpd)
S3method(coef,mev_pp)
S3method(coef,mev_rlarg)
S3method(confint,eprof)
S3method(logLik,mev_egp)
S3method(logLik,mev_gev)
S3method(logLik,mev_gpd)
S3method(logLik,mev_pp)
S3method(logLik,mev_rlarg)
S3method(nobs,mev_egp)
S3method(nobs,mev_gev)
S3method(nobs,mev_gpd)
S3method(nobs,mev_pp)
S3method(nobs,mev_rlarg)
S3method(plot,eprof)
S3method(plot,fr)
S3method(plot,mev_adf)
S3method(plot,mev_ecdf_unif)
S3method(plot,mev_egp_retlev)
S3method(plot,mev_egp_thselect)
S3method(plot,mev_egp_tstab)
S3method(plot,mev_extcoef)
S3method(plot,mev_extremo)
S3method(plot,mev_gev)
S3method(plot,mev_gpd)
S3method(plot,mev_gpdbayes)
S3method(plot,mev_penultimate)
S3method(plot,mev_plot_blocksize)
S3method(plot,mev_pp)
S3method(plot,mev_rlarg)
S3method(plot,mev_shape_rbm)
S3method(plot,mev_taildep)
S3method(plot,mev_taildep_kj)
S3method(plot,mev_test_maxstab)
S3method(plot,mev_thdiag_northropcoleman)
S3method(plot,mev_thselect_automrl)
S3method(plot,mev_thselect_bab)
S3method(plot,mev_thselect_cbm)
S3method(plot,mev_thselect_cv)
S3method(plot,mev_thselect_goks)
S3method(plot,mev_thselect_infomat)
S3method(plot,mev_thselect_lmoment)
S3method(plot,mev_thselect_ncpgp)
S3method(plot,mev_thselect_pickands)
S3method(plot,mev_thselect_vmetric)
S3method(plot,mev_thselect_wadsworth)
S3method(plot,mev_thselect_wcvm)
S3method(plot,mev_tstab.gpd)
S3method(plot,mev_tstab_cv)
S3method(plot,mev_tstab_mrl)
S3method(plot,mev_xacf)
S3method(plot,mev_xdep)
S3method(print,eprof)
S3method(print,mev_egp)
S3method(print,mev_egp_thselect)
S3method(print,mev_gev)
S3method(print,mev_gpd)
S3method(print,mev_gpdbayes)
S3method(print,mev_pp)
S3method(print,mev_test_scoreindep)
S3method(print,mev_thdiag_northropcoleman)
S3method(print,mev_thselect_automrl)
S3method(print,mev_thselect_bab)
S3method(print,mev_thselect_cbm)
S3method(print,mev_thselect_cv)
S3method(print,mev_thselect_expgqt)
S3method(print,mev_thselect_gbw)
S3method(print,mev_thselect_goks)
S3method(print,mev_thselect_infomat)
S3method(print,mev_thselect_lmoment)
S3method(print,mev_thselect_mahalanobis)
S3method(print,mev_thselect_mdps)
S3method(print,mev_thselect_ncpgp)
S3method(print,mev_thselect_pec)
S3method(print,mev_thselect_pickands)
S3method(print,mev_thselect_rbm)
S3method(print,mev_thselect_samsee)
S3method(print,mev_thselect_vmetric)
S3method(print,mev_thselect_wadsworth)
S3method(print,mev_thselect_wcvm)
S3method(summary,eprof)
S3method(vcov,mev_egp)
S3method(vcov,mev_gev)
S3method(vcov,mev_gpd)
S3method(vcov,mev_pp)
S3method(vcov,mev_rlarg)
export(.fit.gpd.rob)
export(.gev.postpred)
export(.gpd_2D_fit)
export(Lambda2cov)
export(NC.diag)
export(PickandsXU)
export(Stein_weights)
export(W.diag)
export(adf)
export(angextrapo)
export(angmeas)
export(angmeasdir)
export(automrl)
export(build.blocks)
export(clikmgp)
export(cvselect)
export(degp)
export(dextgp)
export(dextgp.G)
export(dgeoaniso)
export(dgev)
export(dgp)
export(distg)
export(durbin.unif)
export(egp.fit)
export(egp.fitrange)
export(egp.ll)
export(egp.pll)
export(egp.retlev)
export(egp2.fit)
export(emplik)
export(expme)
export(ext.index)
export(extcoef)
export(extremo)
export(fit.egp)
export(fit.extgp)
export(fit.gev)
export(fit.gevblock)
export(fit.gpd)
export(fit.pp)
export(fit.rho)
export(fit.rlarg)
export(fit.shape)
export(fit.wgpd)
export(gev.Fscore)
export(gev.Nyr)
export(gev.Vfun)
export(gev.abias)
export(gev.bcor)
export(gev.bias)
export(gev.boot)
export(gev.dphi)
export(gev.infomat)
export(gev.ll)
export(gev.ll.optim)
export(gev.mle)
export(gev.phi)
export(gev.pll)
export(gev.retlev)
export(gev.score)
export(gev.tem)
export(gevN.Vfun)
export(gevN.dphi)
export(gevN.infomat)
export(gevN.ll)
export(gevN.mean)
export(gevN.phi)
export(gevN.score)
export(gevblock.ll)
export(gevr.Vfun)
export(gevr.dphi)
export(gevr.infomat)
export(gevr.ll)
export(gevr.ll.optim)
export(gevr.phi)
export(gevr.score)
export(gp.fit)
export(gpd.Fscore)
export(gpd.Vfun)
export(gpd.abias)
export(gpd.bcor)
export(gpd.bias)
export(gpd.boot)
export(gpd.dphi)
export(gpd.infomat)
export(gpd.ll)
export(gpd.ll.optim)
export(gpd.lmom)
export(gpd.mle)
export(gpd.phi)
export(gpd.pll)
export(gpd.score)
export(gpd.tem)
export(gpdN.Vfun)
export(gpdN.dphi)
export(gpdN.infomat)
export(gpdN.ll)
export(gpdN.mean)
export(gpdN.phi)
export(gpdN.quant)
export(gpdN.score)
export(gpde.Vfun)
export(gpde.dphi)
export(gpde.infomat)
export(gpde.ll)
export(gpde.ll.optim)
export(gpde.phi)
export(gpde.score)
export(gpdr.Vfun)
export(gpdr.dphi)
export(gpdr.infomat)
export(gpdr.ll)
export(gpdr.ll.optim)
export(gpdr.phi)
export(gpdr.score)
export(gpdtopar)
export(ibvpot)
export(infomat.test)
export(intensBR)
export(intensXstud)
export(jac_gpd_pareto)
export(kjtail)
export(lambdadep)
export(likmgp)
export(maxstable)
export(maxstabtest)
export(mgp.cll)
export(mgp.ll)
export(mvrnorm)
export(pegp)
export(penultimate)
export(pextgp)
export(pextgp.G)
export(pgev)
export(pgp)
export(power.vario)
export(powerexp.cor)
export(pp.infomat)
export(pp.ll)
export(pp.score)
export(qegp)
export(qextgp)
export(qextgp.G)
export(qgev)
export(qgp)
export(qqplot.blocksize)
export(qqplot.unif)
export(qweissman)
export(rdir)
export(regp)
export(rextgp)
export(rextgp.G)
export(rgev)
export(rgp)
export(rgparp)
export(rho.dk)
export(rho.fagh)
export(rho.gbw)
export(rho.ghp)
export(rlarg.infomat)
export(rlarg.ll)
export(rlarg.score)
export(rmar1)
export(rmev)
export(rmevspec)
export(rmnorm)
export(rparp)
export(rparpcs)
export(rparpcshr)
export(rrlarg)
export(schlather.vario)
export(scoreindep)
export(shape.erm)
export(shape.genjack)
export(shape.genquant)
export(shape.hill)
export(shape.lthill)
export(shape.moment)
export(shape.osz)
export(shape.pickands)
export(shape.rbm)
export(shape.trimhill)
export(shape.vries)
export(smith.penult)
export(smith.penult.fn)
export(spline.corr)
export(spunif)
export(stein_gp_lik)
export(taildep)
export(tem.corr)
export(test.blocksize)
export(test.maxstab)
export(test.scoreindep)
export(test.unif)
export(thselect.alrs)
export(thselect.bab)
export(thselect.cbm)
export(thselect.cv)
export(thselect.egp)
export(thselect.expgqt)
export(thselect.gbw)
export(thselect.goks)
export(thselect.ksmd)
export(thselect.mdps)
export(thselect.mrl)
export(thselect.ncpgp)
export(thselect.pec)
export(thselect.pickands)
export(thselect.rbm)
export(thselect.samsee)
export(thselect.sdinfo)
export(thselect.vmetric)
export(thselect.wcvm)
export(thselect.wseq)
export(tstab.cv)
export(tstab.egp)
export(tstab.gpd)
export(tstab.hill)
export(tstab.lthill)
export(tstab.mrl)
export(xacf)
export(xasym)
export(xdep.asym)
export(xdep.chi)
export(xdep.chibar)
export(xdep.eta)
export(xdep.xcoef)
export(xdep.xindex)
import(stats)
importFrom("utils","combn")
importFrom('graphics','plot.new')
importFrom('graphics','plot.window')
importFrom(Rcpp,evalCpp)
importFrom(Rcpp,sourceCpp)
importFrom(Rsolnp,solnp)
importFrom(alabama,auglag)
importFrom(alabama,constrOptim.nl)
importFrom(grDevices,"colorRampPalette")
importFrom(grDevices,"gray.colors")
importFrom(grDevices,grey.colors)
importFrom(grDevices,hcl.colors)
importFrom(grDevices,rgb)
importFrom(graphics,"abline")
importFrom(graphics,"axis")
importFrom(graphics,"image")
importFrom(graphics,"legend")
importFrom(graphics,"lines")
importFrom(graphics,"matplot")
importFrom(graphics,"mtext")
importFrom(graphics,"par")
importFrom(graphics,"rug")
importFrom(graphics,"text")
importFrom(graphics,arrows)
importFrom(graphics,hist)
importFrom(graphics,layout)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,segments)
importFrom(graphics,title)
importFrom(methods,formalArgs)
importFrom(nleqslv,nleqslv)
importFrom(utils,bibentry)
importFrom(utils,capture.output)
importFrom(utils,head)
importFrom(utils,tail)
useDynLib(mev, .registration = TRUE)
